@@ -39,6 +39,15 @@ class Compose:
     def __init__(
         self,
         func: OptionalFn = None,
+        enable_powertools: bool = False,
+        log_event=True,
+        capture_response=True,
+        capture_error=True,
+        raise_on_empty_metrics=False,
+        capture_cold_start_metric=True,
+        default_dimentions=None,
+        model=None,
+        envelope=None,
         timeout: Optional[Duration] = None,
         is_map_job: bool = False,
         runtime: Optional[Runtime] = None,
@@ -66,6 +75,15 @@ class Compose:
         Args:
             func: a function or list or tuple of functions
             timeout: the timeout duration of the lambda
+            enable_powertools: if true, enables powertools
+            log_event: passed to aws_lambda_powertools.Logger
+            capture_response: passed to aws_lambda_powertools.Tracer
+            capture_error: passed to aws_lambda_powertools.Tracer
+            raise_on_empty_metrics: passed to aws_lambda_powertools.Metrics
+            capture_cold_start_metric: passed to aws_lambda_powertools.Metrics
+            default_dimentions: passed to aws_lambda_powertools.Metrics
+            model: passed to aws_lambda_powertools.utilities.parser.event_parser
+            envelope: passed to aws_lambda_powertools.utilities.parser.event_parser
             runtime: the python runtime to use for the lambda
             is_map_job: whether the lambda is a map job
             comment: An optional description for this state. Default: No comment
@@ -86,7 +104,8 @@ class Compose:
             sfn_timeout: Timeout for the state machine. Default: - None
             **aws_lambda_constructor_kwargs: pass directly to sfn.PythonFunction
 
-        For more info see https://docs.aws.amazon.com/cdk/api/latest/python/modules.html
+        For cdk params see https://docs.aws.amazon.com/cdk/api/latest/python/modules.html
+        For powertools params see https://awslabs.github.io/aws-lambda-powertools-python/latest/
         """
 
         self.func = func
@@ -134,6 +153,19 @@ class Compose:
             self.index = Path(*module).name + ".py"
             self.handler = func.__name__
 
+        self.enable_powertools = enable_powertools
+
+        self.powertools_kwargs = dict(
+            log_event=log_event,
+            capture_error=capture_error,
+            capture_response=capture_response,
+            capture_cold_start_metric=capture_cold_start_metric,
+            raise_on_empty_metrics=raise_on_empty_metrics,
+            default_dimentions=default_dimentions,
+            model=model,
+            envelope=envelope,
+        )
+
     def __call__(self, event, context=None):
 
         if isinstance(self.func, (list, tuple)):
@@ -142,17 +174,35 @@ class Compose:
 
         if self.func is not None:
 
-            return self.func(event, context)
+            if self.enable_powertools:
+
+                return powertools(
+                    decorated=self.func,
+                    **self.powertools_kwargs,
+                )(event, context)
+
+            else:
+
+                return self.func(event, context)
 
         else:
 
             func = event
 
+            sfn_timeout = self.lambda_invoke_kwargs.pop("timeout")
+
             return Compose(
                 func=func,
                 timeout=self.timeout,
                 is_map_job=self.is_map_job,
-                **self.aws_lambda_constructor_kwargs,
+                sfn_timeout=sfn_timeout,
+                enable_powertools=self.enable_powertools,
+                **{
+                    **self.map_job_kwargs,
+                    **self.lambda_invoke_kwargs,
+                    **self.powertools_kwargs,
+                    **self.aws_lambda_constructor_kwargs,
+                },
             )
 
     def __repr__(self) -> str:
@@ -494,7 +544,7 @@ def powertools(
     """
 
     from aws_lambda_powertools import Logger, Tracer, Metrics
-    from aws_lambda_powertools.utilities.parser import event_parser
+    from aws_lambda_powertools.utilities.parser import parse
 
     def decorator(func):
 
@@ -505,7 +555,7 @@ def powertools(
             )
 
         logger, tracer, metrics = (
-            globals().get(x)
+            func.__globals__.get(x)
             for x in (
                 "logger",
                 "tracer",
@@ -516,23 +566,26 @@ def powertools(
         if isinstance(logger, Logger):
 
             func = logger.inject_lambda_context(
+                lambda_handler=func,
                 log_event=log_event,
-            )(func)
+            )
 
         if isinstance(tracer, Tracer):
 
             func = tracer.capture_lambda_handler(
+                lambda_handler=func,
                 capture_response=capture_response,
                 capture_error=capture_error,
-            )(func)
+            )
 
         if isinstance(metrics, Metrics):
 
             func = metrics.log_metrics(
+                lambda_handler=func,
                 capture_cold_start_metric=capture_cold_start_metric,
                 raise_on_empty_metrics=raise_on_empty_metrics,
                 default_dimensions=default_dimentions,
-            )(func)
+            )
 
         if model is not None:
 
@@ -542,17 +595,15 @@ def powertools(
                 Exists because event_parser expects the function it wraps to be named "handler".
                 """
 
-                result = event_parser(
-                    handler=func,
+                parsed_event = parse(
+                    event=event,
                     model=model,
                     envelope=envelope,
-                    event=event,
-                    context=context,
                 )
 
-                return result
+                return func(parsed_event, context)
 
-            func = mini_decorator
+            return mini_decorator
 
         return func
 
